@@ -21,14 +21,21 @@ sub serve {
 
    my ($cmd, $fd);
 
-   local $SIG{CHLD} = 'IGNORE';
-
    my $error = sub {
       warn "[$0] ERROR: $_[0]\n";
       last;
    };
 
+   local *run_args = sub () { # AnyEvent::Fork::Serve::run_args
+      my (@ret, @arg) = @arg; # copy and clear @arg
+      @ret
+   };
+
    while () {
+      # we manually reap child processes before we sleep, as local $SIG...
+      # will destroy existing child handlers instead of restoring them.
+      1 while 0 < waitpid -1, 1; # WNOHANG is portably 1. prove me wrong.
+
       # we must not ever read "too much" data, as we might accidentally read
       # an IO::FDPass::send request.
 
@@ -55,7 +62,7 @@ sub serve {
          my $pid = fork;
 
          if ($pid eq 0) {
-            $0 = "AnyEvent::Fork of $OWNER";
+            $0 = "$OWNER AnyEvent::Fork";
             $master = pop @arg;
 
          } else {
@@ -68,7 +75,7 @@ sub serve {
       } elsif ($cmd eq "e") {
          ($cmd, @_) = unpack "(w/a*)*", $buf;
 
-         # $cmd is allowed to access @_ and @arg, and nothing else
+         # $cmd is allowed to access @_ and nothing else
          package main;
          eval $cmd;
          $error->("$@") if $@;
@@ -77,7 +84,7 @@ sub serve {
          # we could free &serve etc., but this might just unshare
          # memory that could be shared otherwise.
          @_ = ($master, @arg);
-         $0 = "$buf of $OWNER";
+         $0 = "$OWNER $buf";
          package main;
          goto &$buf;
 
@@ -99,7 +106,7 @@ sub me {
 
    $OWNER = $ARGV[1];
 
-   $0 = "AnyEvent::Fork/exec of $OWNER";
+   $0 = "$OWNER AnyEvent::Fork/exec";
 
    @ARGV = ();
    @_ = $fh;
